Monotonicity — Map of Objects

Skip to main content
`Ctrl`+`K`

# Monotonicity

calculate_monotonicity(experiment: Experiment, election_ids: list[str] | None = None, max_distance_percentage: float = 1.0, error_tolerance: float = 0.0) → dict

  Calculate the monotonicity of the distances between the points in the experiment.

calculate_monotonicity_naive(experiment: Experiment, election_ids: list[str] | None = None, max_distance_percentage: float = 1.0, error_tolerance: float = 0.0) → dict

  Calculate the monotonicity of the distances between the points in the experiment using a naive approach.